@@ -29,6 +29,15 @@ if TYPE_CHECKING:
     from narwhals._utils import Implementation, Version
     from narwhals.typing import ConcatMethod, IntoDType, NonNestedLiteral, PythonLiteral
 
+# Adjust slight SQL vs PySpark differences
+FUNCTION_REMAPPINGS = {
+    "starts_with": "startswith",
+    "ends_with": "endswith",
+    "trim": "btrim",
+    "str_split": "split",
+    "regexp_matches": "regexp",
+}
+
 
 class SparkLikeNamespace(
     SQLNamespace[SparkLikeLazyFrame, SparkLikeExpr, "SQLFrameDataFrame", "Column"]
@@ -55,8 +64,7 @@ class SparkLikeNamespace(
             from sqlframe.base import functions
 
             return functions
-        else:
-            return import_functions(self._implementation)
+        return import_functions(self._implementation)
 
     @property
     def _native_dtypes(self):  # type: ignore[no-untyped-def] # noqa: ANN202
@@ -64,17 +72,20 @@ class SparkLikeNamespace(
             from sqlframe.base import types
 
             return types
-        else:
-            return import_native_dtypes(self._implementation)
+        return import_native_dtypes(self._implementation)
 
     def _function(self, name: str, *args: Column | PythonLiteral) -> Column:
-        return getattr(self._F, name)(*args)
+        return getattr(self._F, FUNCTION_REMAPPINGS.get(name, name))(*args)
 
     def _lit(self, value: Any) -> Column:
         return self._F.lit(value)
 
-    def _when(self, condition: Column, value: Column) -> Column:
-        return self._F.when(condition, value)
+    def _when(
+        self, condition: Column, value: Column, otherwise: Column | None = None
+    ) -> Column:
+        if otherwise is None:
+            return self._F.when(condition, value)
+        return self._F.when(condition, value).otherwise(otherwise)
 
     def _coalesce(self, *exprs: Column) -> Column:
         return self._F.coalesce(*exprs)
